# frozen_string_literal: true

require 'spec_helper'

describe Overcommit::Hook::PreCommit::Mdl do
  let(:config)  { Overcommit::ConfigurationLoader.default_configuration }
  let(:context) { double('context') }
  subject { described_class.new(config, context) }

  let(:result) { double('result') }

  before do
    result.stub(success?: success, stdout: stdout, stderr: stderr)
    subject.stub(:applicable_files).and_return(%w[file1.md file2.md])
    subject.stub(:execute).and_return(result)
  end

  context 'when mdl exits successfully' do
    let(:success) { true }
    let(:stdout) { '' }
    let(:stderr) { '' }

    it { should pass }
  end

  context 'when mdl exits unsuccessfully' do
    let(:success) { false }
    let(:message) { subject.run.last }

    context 'and it reports an error' do
      let(:stdout) do
        '[{"filename":"file1.md","line":1,"rule":"MD013","aliases":["line-length"],'\
        '"description":"Line length"}]'
      end
      let(:stderr) { '' }

      it { should fail_hook }
      it { expect(message.file).to eq 'file1.md' }
      it { expect(message.line).to eq 1 }
      it { expect(message.content).to eq 'file1.md:1 MD013 Line length' }
    end

    context 'when there is an error running mdl' do
      let(:stdout) { '' }
      let(:stderr) { 'Some runtime error' }

      it { should fail_hook }
      it { expect(message).to eq 'Some runtime error' }
    end
  end
end
